@@ -550,26 +550,13 @@ class FormattingTests(SimpleTestCase):
                 self.assertIn(
                     "23", time_format(some_datetime)
                 )  # Uses TIME_FORMAT by default
+                self.assertIn("2017", date_format(some_datetime, "DATETIME_FORMAT"))
+                self.assertIn("2017", date_format(some_date, "YEAR_MONTH_FORMAT"))
+                self.assertIn("14", date_format(some_date, "MONTH_DAY_FORMAT"))
+                self.assertIn("2017", date_format(some_date, "SHORT_DATE_FORMAT"))
                 self.assertIn(
                     "2017",
-                    date_format(some_datetime, format=get_format("DATETIME_FORMAT")),
-                )
-                self.assertIn(
-                    "2017",
-                    date_format(some_date, format=get_format("YEAR_MONTH_FORMAT")),
-                )
-                self.assertIn(
-                    "14", date_format(some_date, format=get_format("MONTH_DAY_FORMAT"))
-                )
-                self.assertIn(
-                    "2017",
-                    date_format(some_date, format=get_format("SHORT_DATE_FORMAT")),
-                )
-                self.assertIn(
-                    "2017",
-                    date_format(
-                        some_datetime, format=get_format("SHORT_DATETIME_FORMAT")
-                    ),
+                    date_format(some_datetime, "SHORT_DATETIME_FORMAT"),
                 )
 
     def test_locale_independent(self):
@@ -961,7 +948,7 @@ class FormattingTests(SimpleTestCase):
                     Template('{{ dt|date:"SHORT_DATETIME_FORMAT" }}').render(self.ctxt),
                 )
                 self.assertEqual(
-                    date_format(datetime.datetime.now(), "DATE_FORMAT"),
+                    date_format(datetime.datetime.now()),
                     Template('{% now "DATE_FORMAT" %}').render(self.ctxt),
                 )
 
@@ -1766,55 +1753,32 @@ class MiscTests(SimpleTestCase):
                 )
 
     def test_parse_literal_http_header(self):
-        """
-        Now test that we parse a literal HTTP header correctly.
-        """
-        g = get_language_from_request
-        r = self.rf.get("/")
-        r.COOKIES = {}
-        r.META = {"HTTP_ACCEPT_LANGUAGE": "pt-br"}
-        self.assertEqual("pt-br", g(r))
-
-        r.META = {"HTTP_ACCEPT_LANGUAGE": "pt"}
-        self.assertEqual("pt", g(r))
-
-        r.META = {"HTTP_ACCEPT_LANGUAGE": "es,de"}
-        self.assertEqual("es", g(r))
-
-        r.META = {"HTTP_ACCEPT_LANGUAGE": "es-ar,de"}
-        self.assertEqual("es-ar", g(r))
-
-        # This test assumes there won't be a Django translation to a US
-        # variation of the Spanish language, a safe assumption. When the
-        # user sets it as the preferred language, the main 'es'
-        # translation should be selected instead.
-        r.META = {"HTTP_ACCEPT_LANGUAGE": "es-us"}
-        self.assertEqual(g(r), "es")
-
-        # This tests the following scenario: there isn't a main language (zh)
-        # translation of Django but there is a translation to variation (zh-hans)
-        # the user sets zh-hans as the preferred language, it should be selected
-        # by Django without falling back nor ignoring it.
-        r.META = {"HTTP_ACCEPT_LANGUAGE": "zh-hans,de"}
-        self.assertEqual(g(r), "zh-hans")
-
-        r.META = {"HTTP_ACCEPT_LANGUAGE": "NL"}
-        self.assertEqual("nl", g(r))
-
-        r.META = {"HTTP_ACCEPT_LANGUAGE": "fy"}
-        self.assertEqual("fy", g(r))
-
-        r.META = {"HTTP_ACCEPT_LANGUAGE": "ia"}
-        self.assertEqual("ia", g(r))
-
-        r.META = {"HTTP_ACCEPT_LANGUAGE": "sr-latn"}
-        self.assertEqual("sr-latn", g(r))
-
-        r.META = {"HTTP_ACCEPT_LANGUAGE": "zh-hans"}
-        self.assertEqual("zh-hans", g(r))
-
-        r.META = {"HTTP_ACCEPT_LANGUAGE": "zh-hant"}
-        self.assertEqual("zh-hant", g(r))
+        tests = [
+            ("pt-br", "pt-br"),
+            ("pt", "pt"),
+            ("es,de", "es"),
+            ("es-a,de", "es"),
+            # There isn't a Django translation to a US variation of the Spanish
+            # language, a safe assumption. When the user sets it as the
+            # preferred language, the main 'es' translation should be selected
+            # instead.
+            ("es-us", "es"),
+            # There isn't a main language (zh) translation of Django but there
+            # is a translation to variation (zh-hans) the user sets zh-hans as
+            # the preferred language, it should be selected without falling
+            # back nor ignoring it.
+            ("zh-hans,de", "zh-hans"),
+            ("NL", "nl"),
+            ("fy", "fy"),
+            ("ia", "ia"),
+            ("sr-latn", "sr-latn"),
+            ("zh-hans", "zh-hans"),
+            ("zh-hant", "zh-hant"),
+        ]
+        for header, expected in tests:
+            with self.subTest(header=header):
+                request = self.rf.get("/", headers={"accept-language": header})
+                self.assertEqual(get_language_from_request(request), expected)
 
     @override_settings(
         LANGUAGES=[
@@ -1834,23 +1798,19 @@ class MiscTests(SimpleTestCase):
         refs #18419 -- this is explicitly for browser compatibility
         """
         g = get_language_from_request
-        r = self.rf.get("/")
-        r.COOKIES = {}
-        r.META = {"HTTP_ACCEPT_LANGUAGE": "zh-cn,en"}
-        self.assertEqual(g(r), "zh-hans")
+        request = self.rf.get("/", headers={"accept-language": "zh-cn,en"})
+        self.assertEqual(g(request), "zh-hans")
 
-        r.META = {"HTTP_ACCEPT_LANGUAGE": "zh-tw,en"}
-        self.assertEqual(g(r), "zh-hant")
+        request = self.rf.get("/", headers={"accept-language": "zh-tw,en"})
+        self.assertEqual(g(request), "zh-hant")
 
     def test_special_fallback_language(self):
         """
         Some languages may have special fallbacks that don't follow the simple
         'fr-ca' -> 'fr' logic (notably Chinese codes).
         """
-        r = self.rf.get("/")
-        r.COOKIES = {}
-        r.META = {"HTTP_ACCEPT_LANGUAGE": "zh-my,en"}
-        self.assertEqual(get_language_from_request(r), "zh-hans")
+        request = self.rf.get("/", headers={"accept-language": "zh-my,en"})
+        self.assertEqual(get_language_from_request(request), "zh-hans")
 
     def test_subsequent_code_fallback_language(self):
         """
@@ -1865,46 +1825,37 @@ class MiscTests(SimpleTestCase):
             ("zh-hant-tw", "zh-hant"),
             ("zh-hant-SG", "zh-hant"),
         ]
-        r = self.rf.get("/")
-        r.COOKIES = {}
         for value, expected in tests:
             with self.subTest(value=value):
-                r.META = {"HTTP_ACCEPT_LANGUAGE": f"{value},en"}
-                self.assertEqual(get_language_from_request(r), expected)
+                request = self.rf.get("/", headers={"accept-language": f"{value},en"})
+                self.assertEqual(get_language_from_request(request), expected)
 
     def test_parse_language_cookie(self):
-        """
-        Now test that we parse language preferences stored in a cookie correctly.
-        """
         g = get_language_from_request
-        r = self.rf.get("/")
-        r.COOKIES = {settings.LANGUAGE_COOKIE_NAME: "pt-br"}
-        r.META = {}
-        self.assertEqual("pt-br", g(r))
+        request = self.rf.get("/")
+        request.COOKIES[settings.LANGUAGE_COOKIE_NAME] = "pt-br"
+        self.assertEqual("pt-br", g(request))
 
-        r.COOKIES = {settings.LANGUAGE_COOKIE_NAME: "pt"}
-        r.META = {}
-        self.assertEqual("pt", g(r))
+        request.COOKIES[settings.LANGUAGE_COOKIE_NAME] = "pt"
+        self.assertEqual("pt", g(request))
 
-        r.COOKIES = {settings.LANGUAGE_COOKIE_NAME: "es"}
-        r.META = {"HTTP_ACCEPT_LANGUAGE": "de"}
-        self.assertEqual("es", g(r))
+        request = self.rf.get("/", headers={"accept-language": "de"})
+        request.COOKIES[settings.LANGUAGE_COOKIE_NAME] = "es"
+        self.assertEqual("es", g(request))
 
-        # This test assumes there won't be a Django translation to a US
-        # variation of the Spanish language, a safe assumption. When the
-        # user sets it as the preferred language, the main 'es'
-        # translation should be selected instead.
-        r.COOKIES = {settings.LANGUAGE_COOKIE_NAME: "es-us"}
-        r.META = {}
-        self.assertEqual(g(r), "es")
-
-        # This tests the following scenario: there isn't a main language (zh)
-        # translation of Django but there is a translation to variation (zh-hans)
-        # the user sets zh-hans as the preferred language, it should be selected
-        # by Django without falling back nor ignoring it.
-        r.COOKIES = {settings.LANGUAGE_COOKIE_NAME: "zh-hans"}
-        r.META = {"HTTP_ACCEPT_LANGUAGE": "de"}
-        self.assertEqual(g(r), "zh-hans")
+        # There isn't a Django translation to a US variation of the Spanish
+        # language, a safe assumption. When the user sets it as the preferred
+        # language, the main 'es' translation should be selected instead.
+        request = self.rf.get("/")
+        request.COOKIES[settings.LANGUAGE_COOKIE_NAME] = "es-us"
+        self.assertEqual(g(request), "es")
+        # There isn't a main language (zh) translation of Django but there is a
+        # translation to variation (zh-hans) the user sets zh-hans as the
+        # preferred language, it should be selected without falling back nor
+        # ignoring it.
+        request = self.rf.get("/", headers={"accept-language": "de"})
+        request.COOKIES[settings.LANGUAGE_COOKIE_NAME] = "zh-hans"
+        self.assertEqual(g(request), "zh-hans")
 
     @override_settings(
         USE_I18N=True,
@@ -2005,12 +1956,10 @@ class MiscTests(SimpleTestCase):
         previously valid should not be used (#14170).
         """
         g = get_language_from_request
-        r = self.rf.get("/")
-        r.COOKIES = {}
-        r.META = {"HTTP_ACCEPT_LANGUAGE": "pt-br"}
-        self.assertEqual("pt-br", g(r))
+        request = self.rf.get("/", headers={"accept-language": "pt-br"})
+        self.assertEqual("pt-br", g(request))
         with self.settings(LANGUAGES=[("en", "English")]):
-            self.assertNotEqual("pt-br", g(r))
+            self.assertNotEqual("pt-br", g(request))
 
     def test_i18n_patterns_returns_list(self):
         with override_settings(USE_I18N=False):
@@ -2187,8 +2136,22 @@ class UnprefixedDefaultLanguageTests(SimpleTestCase):
         response = self.client.get("/fr/simple/")
         self.assertEqual(response.content, b"Oui")
 
-    def test_unprefixed_language_other_than_accept_language(self):
-        response = self.client.get("/simple/", HTTP_ACCEPT_LANGUAGE="fr")
+    def test_unprefixed_language_with_accept_language(self):
+        """'Accept-Language' is respected."""
+        response = self.client.get("/simple/", headers={"accept-language": "fr"})
+        self.assertRedirects(response, "/fr/simple/")
+
+    def test_unprefixed_language_with_cookie_language(self):
+        """A language set in the cookies is respected."""
+        self.client.cookies.load({settings.LANGUAGE_COOKIE_NAME: "fr"})
+        response = self.client.get("/simple/")
+        self.assertRedirects(response, "/fr/simple/")
+
+    def test_unprefixed_language_with_non_valid_language(self):
+        response = self.client.get("/simple/", headers={"accept-language": "fi"})
+        self.assertEqual(response.content, b"Yes")
+        self.client.cookies.load({settings.LANGUAGE_COOKIE_NAME: "fi"})
+        response = self.client.get("/simple/")
         self.assertEqual(response.content, b"Yes")
 
     def test_page_with_dash(self):
@@ -2250,35 +2213,34 @@ class CountrySpecificLanguageTests(SimpleTestCase):
 
     def test_get_language_from_request(self):
         # issue 19919
-        r = self.rf.get("/")
-        r.COOKIES = {}
-        r.META = {"HTTP_ACCEPT_LANGUAGE": "en-US,en;q=0.8,bg;q=0.6,ru;q=0.4"}
-        lang = get_language_from_request(r)
+        request = self.rf.get(
+            "/", headers={"accept-language": "en-US,en;q=0.8,bg;q=0.6,ru;q=0.4"}
+        )
+        lang = get_language_from_request(request)
         self.assertEqual("en-us", lang)
-        r = self.rf.get("/")
-        r.COOKIES = {}
-        r.META = {"HTTP_ACCEPT_LANGUAGE": "bg-bg,en-US;q=0.8,en;q=0.6,ru;q=0.4"}
-        lang = get_language_from_request(r)
+
+        request = self.rf.get(
+            "/", headers={"accept-language": "bg-bg,en-US;q=0.8,en;q=0.6,ru;q=0.4"}
+        )
+        lang = get_language_from_request(request)
         self.assertEqual("bg", lang)
 
     def test_get_language_from_request_null(self):
         lang = trans_null.get_language_from_request(None)
-        self.assertEqual(lang, "en")
-        with override_settings(LANGUAGE_CODE="de"):
-            lang = trans_null.get_language_from_request(None)
-            self.assertEqual(lang, "de")
+        self.assertEqual(lang, None)
 
     def test_specific_language_codes(self):
         # issue 11915
-        r = self.rf.get("/")
-        r.COOKIES = {}
-        r.META = {"HTTP_ACCEPT_LANGUAGE": "pt,en-US;q=0.8,en;q=0.6,ru;q=0.4"}
-        lang = get_language_from_request(r)
+        request = self.rf.get(
+            "/", headers={"accept-language": "pt,en-US;q=0.8,en;q=0.6,ru;q=0.4"}
+        )
+        lang = get_language_from_request(request)
         self.assertEqual("pt-br", lang)
-        r = self.rf.get("/")
-        r.COOKIES = {}
-        r.META = {"HTTP_ACCEPT_LANGUAGE": "pt-pt,en-US;q=0.8,en;q=0.6,ru;q=0.4"}
-        lang = get_language_from_request(r)
+
+        request = self.rf.get(
+            "/", headers={"accept-language": "pt-pt,en-US;q=0.8,en;q=0.6,ru;q=0.4"}
+        )
+        lang = get_language_from_request(request)
         self.assertEqual("pt-br", lang)
 
 
