@@ -15,7 +15,7 @@ from django.db import NotSupportedError, connection
 from django.db.models import CharField, F, Index, Q
 from django.db.models.functions import Cast, Collate, Length, Lower
 from django.test import skipUnlessDBFeature
-from django.test.utils import modify_settings, register_lookup
+from django.test.utils import register_lookup
 
 from . import PostgreSQLSimpleTestCase, PostgreSQLTestCase
 from .fields import SearchVector, SearchVectorField
@@ -235,7 +235,6 @@ class SpGistIndexTests(IndexTestMixin, PostgreSQLSimpleTestCase):
         )
 
 
-@modify_settings(INSTALLED_APPS={"append": "django.contrib.postgres"})
 class SchemaTests(PostgreSQLTestCase):
     get_opclass_query = """
         SELECT opcname, c.relname FROM pg_opclass AS oc
@@ -505,7 +504,6 @@ class SchemaTests(PostgreSQLTestCase):
             index_name, self.get_constraints(CharFieldModel._meta.db_table)
         )
 
-    @skipUnlessDBFeature("supports_covering_gist_indexes")
     def test_gist_include(self):
         index_name = "scene_gist_include_setting"
         index = GistIndex(name=index_name, fields=["scene"], include=["setting"])
@@ -519,20 +517,6 @@ class SchemaTests(PostgreSQLTestCase):
             editor.remove_index(Scene, index)
         self.assertNotIn(index_name, self.get_constraints(Scene._meta.db_table))
 
-    def test_gist_include_not_supported(self):
-        index_name = "gist_include_exception"
-        index = GistIndex(fields=["scene"], name=index_name, include=["setting"])
-        msg = "Covering GiST indexes require PostgreSQL 12+."
-        with self.assertRaisesMessage(NotSupportedError, msg):
-            with mock.patch(
-                "django.db.backends.postgresql.features.DatabaseFeatures."
-                "supports_covering_gist_indexes",
-                False,
-            ):
-                with connection.schema_editor() as editor:
-                    editor.add_index(Scene, index)
-        self.assertNotIn(index_name, self.get_constraints(Scene._meta.db_table))
-
     def test_tsvector_op_class_gist_index(self):
         index_name = "tsvector_op_class_gist"
         index = GistIndex(
